module TweekCatalogue
  module Concerns
    module ObjectFactories
      extend ActiveSupport::Concern

      module ClassMethods

        def update_or_create!(primary_key, attrs)
          map_id!(primary_key) if primary_key.present?

          record = first(primary_key)
          if record
            record.update_attributes(attrs)
            record
          else
            create!(primary_key.merge(attrs))
          end
        end

        def first_or_create!(primary_key, attrs = {})
          map_id!(primary_key) if primary_key.present?

          _primary_key = primary_key ? primary_key : send(:build_primary_key, attrs)
          first(_primary_key) || create!(_primary_key.merge(attrs))
        end

        def build_primary_key(*args); raise NotImplementedError end

        private

        def map_id!(attrs)
          attrs[:tmdb_id] = attrs[:tmdb_id].to_s if attrs[:tmdb_id].present?
        end
      end
    end
  end
end
