module TweekCatalogue
  class Participant

    include MongoMapper::Document
    include Concerns::ObjectFactories

    key :video_tmdb_id,  String
    key :person_tmdb_id, String
    key :name, String
    key :work, String # :author, :director, ...
    key :character, String
    key :order, Integer
    key :profile_path, String

    timestamps!

    belongs_to :person, class_name: 'TweekCatalogue::Person'

    scope :not_syncd, -> { where(person_id: nil) }

    def self.build_primary_key(attrs)
      {
        video_tmdb_id:  attrs[:video_tmdb_id].to_s,
        person_tmdb_id: attrs[:person_tmdb_id].to_s,
        character:      attrs[:character].to_s,
        work:           attrs[:work].to_s
      }
    end

    def cast?
      !!character
    end

    def crew?
      !!work
    end

    def type
      return :cast if cast?
      return :crew if crew?
      return :undefined
    end
  end
end
